#!/bin/bash

#####################################################################
# This script is managing the call to setup.sh
# F. Hourdin, hourdin@lmd.jussieu.fr
#####################################################################

# Model & configuration setup
#===========================================================
# Where the model will be installed
# Default for setup.sh : LMDZD=$WORK defined in lmdz_env.sh
wrkgcm=$WORK

#-----------------------------------------------------------
# Version of the tar file on http://www.lmd.jussieu.fr/~lmdz/pub/src
# Can be updated to a more recent svn version with svn=
#version=20200128.trunk
version=trunk
#svn="-r 3590"
svn=""
# ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! !
# NOTE : the default orchidee_rev in this version is 3013.
# ! ! ! ! ! CHECK/CHANGE orchidee_rev in setup.sh ! ! ! ! !

#-----------------------------------------------------------
# Grid number of points IMxJMxLM
resol=144x142x79
#resol=128x88x79

#-----------------------------------------------------------
# avec instalation de LMDZ : -install
#install=""
install=-install

#-----------------------------------------------------------
# Activation of Cosp simulator
cosp="-cosp"
cosp=""

#-----------------------------------------------------------
# Using XIOS for IOs
xios="-xios"
xios=""

#===========================================================
# Simulation setup
#-----------------------------------------------------------

# Initial state and Boundary conditions
# -------------------------------------
# init=   1: to create a new start in INT
#         0: to read start files in INIT
#       SIM: to read start files from previous simulation SIM0
# limit.nc and aerosols forcing are put in ./LIMIT
init=1
#init=SIM0 # SIM0 must be in the same folder as the new SIM

#-----------------------------------------------------------
# climato=1 : Climatological SSTs with 360-day calendar 
#        =0 : interannual SSTs with true (ie gregorian) calendar 
climato=1

#-----------------------------------------------------------
# Nudging: Can be activated only with climato=0 and freq=mo
nudging="-nudging"
nudging=""
#If using nudging, then check DEF/guide.def :
#  - ok_guide will be automatically set to "y" by setup.sh
#  - You may want to check/customize the nudging parameters

#-----------------------------------------------------------
# Length of elementary simulations yr (year) or mo (month)
freq=yr

#-----------------------------------------------------------
# Initial/final month for simulation
# If $init=1, the INIT file will be called start.200001.nc,
# but the data correspond in fact to another day.
# NB : the run stops in the BEGINNING of mthend (test "next=stopsim")
mthini=200001
mthend=200601

#-----------------------------------------------------------
# Output files, frequencies, levels 
#   You may want to choose and customize DEF/config.def 
#   A few versions are available as DEF/config.def_* ; the default corresponds to _outlev_0 
#   See phys_out_filekeys, phys_out_filelevels, phys_out_filetimesteps, and supplementary variables

#-----------------------------------------------------------
# Grid characteristics (regular, zoomed)
#   You may want to choose and customize DEF/gcm.def 
#   A few versions are available as DEF/gcm.def_* ; 
#      The default, for regular grid 144x142x79, corresponds to _iperiod7 
#      (Expert : TEMPORARILY : setup.sh forces use of gcm.def_zNAfrica_BiJe for aerosols=spla)

#===========================================================
# Running a series of simulation.
# -------------------------------
# By default, the series is done on various versions of physiq.def 
# to be chosen among DEF/PHYS/physiq.def_*
physics="NPv6.1"

# JYG : select lmd_phys=new if you want to compile with phynew instead of phylmd.
lmd_phys="lmd"

for phys in $physics ; do
   sed -e 's/ifl_pbltree=1/ifl_pbltree=0/' DEF/PHYS/physiq.def_$phys >| DEF/physiq.def
   # name of simulation (Default : name=$phys , for lmd_phys="lmd" or "")
   #JYG
   name=$phys$lmd_phys
   if [ "$lmd_phys" = "lmd" ] ; then name=$phys ; fi
   if [ "$lmd_phys" = "" ] ; then lmd_phys="lmd" ; fi
   #fin version JYG
   # Question AS : a-t-on besoin de se premunir contre un accident genre lmd_phys="" ? On ne le fait pas pour name, freq, climato...
   #if [ "$lmd_phys" = "lmd" ] ; then name=$phys ; else name=$phys$lmd_phys ; fi

   ./setup.sh -wrkgcm $wrkgcm -d $resol -f $freq -v $version -p $lmd_phys -name $name $svn $install -init $init $cosp $xios -mthini $mthini -mthend $mthend $nudging -climato $climato

# init=1 is possible only for the first simulation
if [ $init = 1 ] ; then init=0 ; fi
done



