#!/bin/bash

#set -vx

sed -i -e 's/hostname=.*.$/hostname='`hostname`'/' lmdz_env.sh
. lmdz_env.sh
module list

# Pour les post-traitements
sed -i'' -e 's/groupe@cpu/'$groupe'@cpu/' seasonal.sh
local=`pwd`

##############################################################

# A function to fetch files either locally or on the internet
function myget { #1st and only argument should be file name
   # Path on local computer where to look for the datafile
   if [ -f /u/lmdz/WWW/LMDZ/pub/$1 ] ; then
     \cp -f -p /u/lmdz/WWW/LMDZ/pub/$1 .
   elif [ -f ~/LMDZ/pub/$1 ] ; then
     \cp -f -p ~/LMDZ/pub/$1 .
   else
     wget -nv http://www.lmd.jussieu.fr/~lmdz/pub/$1
     #dir=~/LMDZ/pub/`dirname $1` ; mkdir -p $dir ; cp -r `basename $1` $dir
   fi
}

##############################################################
# Choices : name, nudging, calendar ...
##############################################################
SIM=`basename \`pwd\``CTL
phylmd=lmd #option -p $phylmd for makelmdz
ok_guide=n

veget=y
# Choice of aerosols : n / clim / spla 
aerosols=clim

cosp=n
xios=n

climato=1
freq=mo  # frequence mensuelle mo ou annuelle yr

# With nudging, use real calendar and monthly integrations
# NB : the run stops in the BEGINNING of mthend (test "next=stopsim")
mthini=200001
mthend=200501
resol=144x142x79

svn=""
version=20160614.trunk
# Choose Orchidee revision number.
# Available: 3013(default in version=20200128.trunk), 4470 , 5004
#orchidee_rev="3013"
orchidee_rev="5004"
sed -i -e 's/orchidee_rev=.*.$/orchidee_rev='$orchidee_rev'/' script_SIMU

install=0
init=1

LIMIT=LIMIT

##############################################################
# Output files, frequency, level 
##############################################################
#   Choose your config.def among the versions available in DEF (default : outlev_0); 
#   edit it and set up output files, frequencies and levels.
#     For aerosols=spla, output level minimum 4 is required to output the specific variables.
#     For aerosols=n, the corresponding flags will automatically be set to "n".

##############################################################
# Controling compilation
##############################################################
fcm=-nofcm
fcm=""
optim="-debug"
optim=""
if [ "$ARCH" = "" ] ; then arch= ; else arch="-arch $ARCH" ; fi
##############################################################

if [ $veget = y ] ; then
#  opt_veget=' -v orchidee2.0 -cpp ORCHIDEE_NOZ0H '
   opt_veget=' -v orchidee2.0 '
  suforch='_orch'
else
  opt_veget=""
  suforch=''
fi

##############################################################

if [ $aerosols = spla ] ; then
  opt_aer=' -dust true '
  sufaer='_spla'
else
  opt_aer=""
  sufaer=''
fi

##############################################################
# options
##############################################################

while (($# > 0))
   do
   case $1 in
     "-h") cat <<........fin
           lance.sh [-v version] [-r svn_release] [-init INIT] [-d 96x95x79] [-f mo] [-nudging]
           "version" like 20150828.trunk ; see http://www.lmd.jussieu.fr/~lmdz/Distrib/LISMOI.trunk
           "svn_release"      either the svn release number or "last"
           -d IMxJMxLM        to run in resolution IM x JM x LM
           -install           pour installer et compiler le modele
           -f mo/yr           pour tourner en mensuel ou annuel
           "INIT"             1: creates INIT and LIMIT
                              0: reads from INIT and LIMIT
                              SIMU: reads from preexisting simulation SIMU and LIMIT
           -nudging           to run with nudging. Nudging files must be created independently
........fin
     exit ;;
     "-v") version=$2 ; shift ; shift ;;
     "-r") svn=$2 ; shift ; shift ;;
     "-d") resol=$2 ; shift ; shift ;;
     "-f") freq=$2 ; shift ; shift ;;
     "-p") phylmd=$2 ; shift ; shift ;;
     "-install") install=1 ; shift ;;
     "-wrkgcm") LMDZD=$2 ; shift ; shift ;;
     "-name") SIM=$2 ; shift ; shift ;;
     "-cosp") cosp=y ; shift ;;
     "-xios") xios=y ; shift ;;
     "-init") init=$2 ; shift ; shift ;;
     "-nudging") ok_guide=y ; shift ;;
     "-climato") climato=$2 ; shift ; shift ;;
     "-mthini") mthini=$2 ; shift ; shift ;;
     "-mthend") mthend=$2 ; shift ; shift ;;
     *) $0 -h ; exit
   esac
done

# Three options for initialisation
# 1: Create INIT
# 0: Take from INIT
# DIR : Take from DIR
if [ $init = 1 -o $init = 0 ] ; then
   INIT=INIT
else
   INIT=$init
fi

if [ $ok_guide = y -a $climato = 1 ] ; then
   echo "================================================================"
   echo Running nudged simulations with climatological SSTs
   echo is not planned. Change climato to 0 or modify the setup \(experts\)
   echo "================================================================"
   exit
fi

if [ $climato = 0 -a $freq = yr ] ; then
   echo "================================================================"
   echo running simulations with interannual SSTs is possible only
   echo month by month and a true calendar.
   echo Change climato to 1 or freq to mo or modify setup.sh \(experts\)
   echo "================================================================"
   exit
fi

if [ "$svn" = "" ] ; then svnopt="" ; else svnopt="-r $svn" ; fi


if [ -d $SIM ] ; then
   echo La simulation $SIM existe deja
   echo Il est preferable d arreter et de verifier.
   echo Si vous etes sur de vous, vous pouvez la prolonger
   echo Voulez vous la prolonger '? (y/o)' 
   read ans
   if [ $ans != y -a $ans != o ] ; then
      exit
   fi
fi

if [ $aerosols = spla -a $resol != 128x88x79 ] ; then
  echo 'For now, aerosols=spla requiers resol=128x88x79, and uses the zoomed grid from gcm.def_zNAfrica_BiJe, for which forcing & initial files are available'
  echo Actual aerosols and resol is $aerosols, $resol
  exit
fi

yearini=`echo $mthini | cut -c-4`
if [ $freq = yr ] ; then stopsim=`echo $mthend | cut -c-4` ; else stopsim=$mthend ; fi

########################################################################
# Recuperation ou compilation du GCM
########################################################################
if [ ! -d $LMDZD ] ; then mkdir -p $LMDZD ; fi


LMDZname=LMDZ$version${svn}$optim
#if [ "$orchidee_rev" != "" ] ; then
if [ "$orchidee_rev" != 3013 ] ; then
   LMDZname=${LMDZname}OR$orchidee_rev
   ins_orch="-orchidee_rev $orchidee_rev"
fi
MODEL=$LMDZD/$LMDZname/modipsl/modeles/LMDZ


if [ $cosp = y ] ; then
   opt_cosp="-cosp true" ; ins_cosp="-cosp"
else
   opt_cosp=""           ; ins_cosp=""
fi

if [ $xios = y ] ; then ins_xios="-xios" ; else ins_xios="" ; fi

if [ $install = 1 ] ; then
   if [ -d $MODEL ] ; then
      echo "Vous essayez d installer une version deja presente"
      exit
   else
      echo On installe le modele
      cd $LMDZD
      echo wget http://www.lmd.jussieu.fr/~lmdz/pub/install_lmdz.sh
      \rm -f install_lmdz.sh
      wget --no-cache http://www.lmd.jussieu.fr/~lmdz/pub/install_lmdz.sh
      chmod +x install_lmdz.sh
      ./install_lmdz.sh $fcm $optim -v $version $svnopt -d $resol -bench 0 -parallel mpi_omp $ins_cosp $ins_xios $ins_orch -name $LMDZname -env_file $local/lmdz_env.sh
      mv install_lmdz.sh install_lmdz.$$
      cd $local
   fi
else
   if [ ! -d $MODEL ] ; then
      echo Le model $MODEL n est pas installe
      echo relancer avec install=1 si vous voulez l installer automatiquement
      exit
   fi
fi


#######################################################################
# Compilation du modele
#######################################################################
# The gcm name defined below is used to check if the executable exists
# It is also used when compiling without fcm : the output of makelmdz is gcm.e, and is renamed as $gcm
gcm=$MODEL/bin/gcm_${resol}_phy${phylmd}_para_mem${suforch}${sufaer}.e
echo $gcm
if [ ! -f $gcm ] ; then
   echo Le model $gcm n existe pas
   echo il va se compiler automatiquement sur $MODEL
   sleep 10
   cd $MODEL
   if [ "$fcm" = "-nofcm" ] ; then
      ./makelmdz $optim -p $phylmd $opt_cosp -rrtm true $arch  -d $resol $opt_veget $opt_aer -mem -parallel mpi_omp $arch  gcm ; mkdir -p bin ; \mv -f gcm.e $gcm
   else
      # makelmdz_fcm directly produces executable named $gcm, depending on the compilation options
      ./makelmdz_fcm $optim -p $phylmd $opt_cosp -rrtm true $arch  -j 8 -d $resol $opt_veget $opt_aer -mem -parallel mpi_omp $arch  gcm
   fi
   if [ ! -f $gcm ] ; then echo la compilation a echoue ; exit ; fi
   cd $local
fi


######################################################################
# Choix du nombre de processeurs
jm=`echo $resol | cut -dx -f2`
(( mpi = ( $jm + 1 ) / 2 ))
omp=8
if [ $aerosols = spla ] ; then omp=1 ; fi
if [ $mpi -gt $nb_mpi_max ] ; then mpi=$nb_mpi_max ; fi
if [ $omp -gt $nb_omp_max ] ; then omp=$nb_omp_max ; fi

######################################################################
# Choix de la grille verticale
######################################################################
if [ ! -d DEF ] ; then echo Recuperer un repertoire DEF ; exit ; fi
lm=`echo $resol | cut -dx -f3`
if [ ! -f DEF/L$lm.def ] ; then echo resolution verticale non prevue
                                 echo creer un fichier DEF/L$lm.def
   exit
else
   sed -i -e 's/INCLUDEDEF=L.*.def/INCLUDEDEF=L'$lm'.def/' DEF/run.def
fi

######################################################################
# Changements dans les fichiers DEF/*def
# (ils vont se repercuter dans les repertoires de simulation $local/$SIM et de run $WRK)
######################################################################

# Choix du fichier traceur.def coherent avec l'option "aerosols"
#---------------------------------------------------------------------
# NB: Si on change de traceur.def (entre spla et nospla), il faut refaire l'etape "initialisation" (ce0l) 
# On s'assure que par defaut on utilise "_nospla", avant de changer pour "spla" le cas echeant
cp DEF/traceur.def_nospla DEF/traceur.def
if [ $aerosols = spla ] ; then cp DEF/traceur.def_spla  DEF/traceur.def ; fi

# TEMPORAIREMENT pour spla on force l'utilisation de gcm.def_zNAfrica_BiJe (avec resolution 128x88x79)
#----------------------------------------------------------------------
if [ $aerosols = spla ] ; then cp DEF/gcm.def_zNAfrica_BiJe DEF/gcm.def ; fi

# Inscription du choix ok_guide dans DEF/guide.def
#---------------------------------------------------------------------
sed -i -e 's/ok_guide=.*.$/ok_guide='$ok_guide'/' DEF/guide.def

# Inscription du type de calendrier (qui est fonction de $climato) dans DEF/run.def
#---------------------------------------------------------------------
# NB Contrairement a ce qui est ecrit dans  les fichiers run.def standard, 
# dans ce tutorial le choix earth_365d n'est pas disponible, et earth_366d s'appelle gregorian
if [ $climato = 0 ] ; then calend=gregorian ; else calend=earth_360d ; fi
sed -i -e 's/calend=.*.$/calend='$calend'/' DEF/run.def

# Changements dans config.def (pre-choisi et regle pour output) cf options veget, aerosols, cosp
#---------------------------------------------------------------------
sed -i -e 's/VEGET=.*.$/VEGET='$veget'/' DEF/config.def

if [ $aerosols = n ] ; then
  ##AS: Ce "sed" etait fait par script_SIMU dans $SCRATCH: il met flag_aerosols=0 et ok_ade&co=n
  sed -i'' -e 's/^ok_cdnc=.*.$/ok_cdnc=n/' -e 's/^ok_ade=.*.$/ok_ade=n/' -e 's/^ok_aie=.*.$/ok_aie=n/' -e 's/^ok_alw=.*.$/ok_alw=n/' -e 's/^flag_aerosol=.*.$/flag_aerosol=0/' DEF/config.def
fi

if [ $cosp = y ] ; then
   sed -i -e 's/ok_cosp.*.$/ok_cosp=y/' DEF/config.def
   \cp -f $MODEL/DefLists/cosp_input_nl.txt $local/DEF/
   \cp -f $MODEL/DefLists/cosp_output_nl.txt $local/DEF/
fi

######################################################################
# Verification de l'existance de l'etat initial et compilation eventuelle
# pour sa creation
######################################################################
if [ ! -d $INIT ] ; then 
   if [ $init = 0 ] ; then
      echo  Recuperer les repertoires $INIT ou lancer avec option -init ; exit
   else
      cd $MODEL
      ce0l=$MODEL/bin/ce0l_${resol}_phy${phylmd}_para_mem${suforch}.e
      if [ "$fcm" = "-nofcm" ] ; then
          ./makelmdz $optim -p $phylmd -rrtm true $arch  -d $resol $opt_veget -mem -parallel mpi_omp $arch  ce0l ; mkdir -p bin ; \mv -f ce0l.e $ce0l
      else
         ./makelmdz_fcm $optim -p $phylmd -rrtm true $arch  -j 8 -d $resol $opt_veget -mem -parallel mpi_omp $arch  ce0l
      fi
      cd $local
   fi
elif [ $init = 1 ] ; then
   echo Vous essayez d initialiser le modele mais $INIT existe deja
   exit
fi

MAINDIR=`basename \`pwd\``


######################################################################
# On cree sur le SCRATCHD un repertoire de travail avec le meme
# nom que le repertoire local
######################################################################
. ./lmdz_env.sh
WRK=$SCRATCHD/$MAINDIR
mkdir -p $WRK
cd $WRK
echo La simuation s executera sur $SCRATCHD/$MAINDIR

#####################################################################
# Creation du repertoire $SIM s il n'existe pas deja
#####################################################################

if [ ! -d $local/$SIM ] ; then
mkdir $local/$SIM
cd $local
sed -e 's/compilo=.*.$/compilo='$compilo'/' -e 's:^rebuild=.*.$:rebuild='$LMDZD/$LMDZname/modipsl/bin/rebuild':' -e 's/groupe@cpu/'$groupe'@cpu/' reb.sh  >| $local/$SIM/reb.sh ; chmod +x $local/$SIM/reb.sh
cp lmdz_env.sh $local/$SIM/
mkdir $local/$SIM/DEF ; cp DEF/*def DEF/cosp*txt $local/$SIM/DEF/
chmod u+w $local/$SIM/DEF/*

# Gestion du calendrier
#######################
sed -e 's/anneeref=.*.$/anneeref='$yearini'/' \
    DEF/run.def >| $local/$SIM/DEF/run.def
cd $SIM
if [ "$freq" = "yr" ] ; then date=$yearini ; else date=$mthini ; fi
echo $date a faire >| etat

# Recuperation des fichiers : executable initiaux et forcages
#############################################################
echo $date 
for f in start startphy ; do inf=../$INIT/$f.$date.nc ; if [ -f $inf -o $init = 1 ] ; then ln -s $inf ./ ; else echo $inf inexistant ; exit ; fi ; done
for f in sechiba stomate ; do if [ -f ../$INIT/start_$f.$date.nc ] ; then ln -sf  ../$INIT/start_$f.$date.nc . ; fi ; done
cp $gcm gcm.e
fi  # fin de " if [ ! -d $local/$SIM ]"
cd $local/..

# Choix du "time limit" pour le job
###################################
if [ "$freq" = "yr" ] ; then cput=04:00:00 ; else cput=01:00:00 ; fi

#####################################################################
echo Modification du script de lancement
###################################################################/$S

sed -e 's/stopsim=.*.$/stopsim='$stopsim'/' -e 's/INIT/'$INIT'/' -e 's/^veget=.*.$/veget='$veget'/' -e 's/^aerosols=.*.$/aerosols='$aerosols'/' -e 's/NOM_SIMU/'$SIM'/' -e 's/time=.*.$/time='$cput'/' -e 's/MAINDIR=.*.$/MAINDIR='$MAINDIR'/' -e 's:STORED=.*.*:STORED='$STORED':'  -e 's:SCRATCHD=.*.*:SCRATCHD='$SCRATCHD':' -e 's/ntasks=.*.$/ntasks='$mpi'/' -e 's/cpus-per-task=.*.$/cpus-per-task='$omp'/' -e 's/nthreads=.*./nthreads='$omp'/' -e 's/^climato=.*.$/climato='$climato'/' -e 's/^ok_guide=.*.$/ok_guide='$ok_guide'/' -e 's/^compilo=.*.$/compilo='$compilo'/' -e 's/groupe@cpu/'$groupe'@cpu/' $local/script_SIMU >| $WRK/tmp_$SIM

if [ $climato = 0 ] ; then
#AS: calend est maintenant choisi plus tot dans "Changements dans les fichiers DEF/*def" et ecrit dans $MAINDIR/DEF/run.def
#calend=gregorian
yrini=`echo $mthini | cut -c-4`
yrend=`echo $mthend | cut -c-4`
yrs="" ; yr=$yrini ; while [ $yr -le $yrend ] ; do yrs="$yrs $yr" ; (( yr = $yr + 1 )) ; done
suf=360x180_
else
#calend=earth_360d
yrs=2000
suf=1x1_clim
fi


#####################################################################
   echo Recuperation eventuelle de certains fichiers sur LMDZ_Init
#####################################################################

if [ ! -d $LMDZ_Init ] ; then mkdir $LMDZ_Init ; fi

#------------------------------------------------------------------- 
# Fichiers ORCHIDEE
#------------------------------------------------------------------- 
get="myget 3DInputData/Orchidee/"
liste_get="PFTmap_IPCC_2000.nc cartepente2d_15min.nc \
             routing.nc lai2D.nc soils_param.nc \
             woodharvest_2000.nc PFTmap_15PFT.v1_2000.nc"
for file in $liste_get ; do 
  if [ ! -f $LMDZ_Init/$file ] ; then cd $LMDZ_Init ; ${get}$file ; cd - ; fi 
done
#------------------------------------------------------------------- 
# Fichiers aerosols/chimie
#------------------------------------------------------------------- 
if [ $aerosols = clim ] ; then
  get="myget 3DInputData/AerChem/"
  liste_get="aerosols1850_from_inca.nc aerosols2000_from_inca.nc" 
  for file in $liste_get ; do 
    if [ ! -f $LMDZ_Init/$file ] ; then cd $LMDZ_Init ; ${get}$file ; cd - ; fi
  done
fi

# For SPLA
# Dans ${LMDZ_Init} on cree folder SPLA_Init
# Pour l'instant on copie là-dedans de chez Binta les fichiers a la res zoomNaf;
# plus tard on y recupererea des fichiers a haute resolution reguliere depuis http:/LMDZ, 
# a regrider ensuite par un script interp_fichiers_spla.sh (comme pour aerosols="clim") 
# Les fichiers regrides seront mis dans $MAINDIR/INPUT_SPLA (equivalent de INPUT_DUST)
if [ $aerosols = spla ] ; then
  if [ ! -d ${LMDZ_Init}/SPLA_Init ] ; then mkdir ${LMDZ_Init}/SPLA_Init ; fi
# Cette liste de fichiers devrait etre suffisante quand on aurait elimine les parties introduites par Jeronimo pour inversion;
# Pourl'instant
# SPLA demande (probablement tous?) les fichiers dans INPUT_DUST/INITIAL de Jeronimo et Binta
# Alors pour l'instant je copie tout simplement le repertoire de Binta:
  cp -pr /gpfsstore/rech/gzi/rgzi027/ergon/BIBIAERO/INPUTS_DUST/INITIAL ${LMDZ_Init}/SPLA_Init/Initial
#  get="cp -p /gpfsstore/rech/gzi/rgzi027/ergon/BIBIAERO/INPUTS_DUST/INITIAL/"
#  liste_get="wth.dat cly.dat donnees_lisa.nc SOILSPEC.data \
#               cv3feed_param.data               \
#               carbon_emissions.nc sulphur_emissions_antro.nc  \
#               sulphur_emissions_nat.nc  sulphur_emissions_volc.nc"
#  for file in $liste_get ; do
#    if [ ! -f $LMDZ_Init/SPLA_Init/$file ] ; then cd $LMDZ_Init/SPLA_Init ; ${get}$file . ; cd - ; fi
#  done
# J'ai mis ces fichiers dans INITIAL_reduit
###
  #Cas particulier des fichiers mensuels dust.nc :A DECIDER : 
  #C'est entre le cas des aerosols.clim= 1 seul fichier, annuel, 
  # et le cas des vents guidage, pré-interpolés avec era2gcm pour toute la periode, dans MAINDIR/GUIDE. 
  # On pourrait (a)demander de precalculer dust.nc aussi, dans MAINDIR/INPUT_SPLA - avec un script à adapter de Jeronimo. Rien a mettre dans SPLA_Init alors. 
  # Ou (b) fournir dans SPLA_Init les 12 mois d'un dust.nc climato (an 2006 pour nous ici) à la res EC, et faire juste le regrid vers MAINDIR/INPUT_SPLA
  #ICI pour l'instant je copie les fichiers de chez Binta (repositoire==http...) dans LMDZ_Init/SPLA_Init, avec test sur mois 01

  if [ ! -d ${LMDZ_Init}/SPLA_Init/PERIOD0001 ] ; then cp -pr /gpfsstore/rech/gzi/rgzi027/ergon/BIBIAERO/INPUTS_DUST/PERIOD* $LMDZ_Init/SPLA_Init/. ; fi

 #A la fin on doit avoir dans SPLA_Init un les fichiers initiaux "en vrac" plus les repertoires PERIOD00MM (contenant dust.nc et modvalues.nc mensuels)
 #Cela doit se retrouver dans script_SIMU qui les copie dans le repertoire de run sur $SCRATCH

fi #$aerosols = spla

#------------------------------------------------------------------- 
# Fichiers Init
#------------------------------------------------------------------- 
get="myget 3DInputData/Init/"
liste_get="alb_bg_modisopt_2D_ESA_v2.nc reftemp.nc"
for file in $liste_get ; do 
  if [ ! -f $LMDZ_Init/$file ] ; then cd $LMDZ_Init ; ${get}$file ; cd - ; fi
done

cd $local



if [ $init = 1 ] ; then
   #####################################################################
      echo Creation de l etat initial
   #####################################################################

   # Creation du repertoire INIT et mise en place de liens logiques vers les starts
   # en anticipation de leur création :
   mkdir $local/$INIT ; cd $local/$INIT
   for an in $mthini $yearini ; do for f in start startphy ; do ln -s $f.nc $f.$an.nc ; done ; done

   # Creation du repertoire INIT temporaire et rapatriement des fichiers necessaires
   if [ -d $WRK/$INIT ] ; then mv $WRK/$INIT $WRK/$INIT$$ ; fi
   mkdir $WRK/$INIT ;  cp -r $local/DEF $WRK/$INIT/
   cd $WRK/$INIT ; cp DEF/* . ; cp $local/lmdz_env.sh .
   sed -e 's/anneeref=.*.$/anneeref='$yearini'/' DEF/run.def >| run.def

#------------------------------------------------------------------- 
# Fichiers Limit
#------------------------------------------------------------------- 
   get="myget 3DInputData/Limit/"
   liste_get="Albedo.nc Relief.nc Rugos.nc landiceref.nc"
   for yr in $yrs ; do
       if [ $climato = 0 ] ; then sufyr=$suf$yr ; else sufyr=$suf ; fi
       liste_get="$liste_get  amipbc_sic_$sufyr.nc amipbc_sst_$sufyr.nc"
   done
   echo LISTEGET $liste_get
   for file in $liste_get ; do
     if [ ! -f $LMDZ_Init/$file ] ; then cd $LMDZ_Init ; ${get}$file ; cd - ; fi
     ln -s $LMDZ_Init/$file
   done
#------------------------------------------------------------------- 
# ECDYN
#------------------------------------------------------------------- 
   get="myget 3DInputData/Init/"
   if [ ! -f $LMDZ_Init/ECDYN.nc ] ; then cd $LMDZ_Init ; ${get}ECDYN.nc ; cd - ; fi
   ln -s $LMDZ_Init/ECDYN.nc
   ln -sf ECDYN.nc ECPHY.nc


   # Creation du script d'initialisation
   cat <<...eod>| tmp
#!/bin/bash

#SBATCH --job-name=Init         # nom du job
#SBATCH -A "$groupe"@cpu
#SBATCH --ntasks=1             # Nombre de processus MPI
#SBATCH --cpus-per-task=16     # nombre de threads OpenMP
# /!\ Attention, la ligne suivante est trompeuse mais dans le vocabulaire
# de Slurm "multithread" fait bien rÃ©fÃ©rence Ã  l'hyperthreading.
#SBATCH --hint=nomultithread   # 1 thread par coeur physique (pas d'hyperthreading)
#SBATCH --time=00:10:00            # Temps dâ€™exÃ©cution maximum demandÃ© (HH:MM:SS)
#SBATCH --output=Init%j.out     # Nom du fichier de sortie
#SBATCH --error=Init%j.out      # Nom du fichier d'erreur (ici commun avec la sortie)


# ANCIEN MULTI STEP  case \${LOADL_STEP_NAME} in

# ANCIEN MULTI STEP   init )

   if [ ! -f lmdz_env.sh ] ; then echo manque fichier lmdz_env.sh ; ls ; exit ; fi
   . lmdz_env.sh
   ulimit -s unlimited
   export OMP_STACKSIZE=800M
   export OMP_NUM_THREADS=1
   cd $WRK/$INIT
   echo Executable : $ce0l
   for yr in $yrs ; do 
      if [ $climato = 0 ] ; then sufyr=$suf\$yr ; else sufyr=$suf ; fi
      ln -sf amipbc_sic_\$sufyr.nc amipbc_sic_1x1.nc
      ln -sf amipbc_sst_\$sufyr.nc amipbc_sst_1x1.nc
      # if [ $climato = 1 ] ; then calend=earth_360d ; elif [ \$(( \$yr % 4 )) = 0 ] ; then calend=earth_366d ; else calend=earth_365d ; fi
      #AS: sed calend inutile : sed -e 's/anneeref=.*.$/anneeref='\$yr'/' -e 's/^calend=.*.$/calend='$calend'/' DEF/run.def >| run.def
      sed -e 's/anneeref=.*.$/anneeref='\$yr'/' DEF/run.def >| run.def
      echo Starting initialisation
      $run 1 $ce0l
      if [ $climato = 0 ] ; then mv limit.nc limit.\$yr.nc ; fi
   done
# ANCIEN MULTI STEP    ;;

# ANCIEN MULTI STEP   interp )
   if [ $aerosols = clim ] ; then
    cp $local/interp_aerosols.sh . ; chmod +x interp_aerosols.sh
    for year in 2000 1850 ; do  ./interp_aerosols.sh \$year ; done
    mv aerosols.2000.nc aerosols.clim.nc ; mv aerosols.1850.nc aerosols.nat.nc
   fi

   # future interpolation pour SPLA, sur $WRK aussi; 
   #en attendant, on passe au paragraphe suivant où on copie directement les fichiers à la res ZoomNaf de $LMDZ_Init/SPLA_Init
   #if [ $aerosols = spla ] ; then
    #cp $local/futur script interp_aerosols_SPLA.sh . ; chmod +x interp_aerosols_SPLA.sh
    #for file in... ; do  ./interp_aerosols.sh \$year ; done
    #mv aerosols.2000.nc aerosols.clim.nc ; mv aerosols.1850.nc aerosols.nat.nc
   #fi

# Copy initial and forcing files in $local/$INIT and $local/$LIMIT; also in $local/INPUT_SPLA if $aerosols=spla
   for f in sta* limit.nc gri*nc ; do cp \$f $local/$INIT/\$f ; done
   mkdir -p $local/$LIMIT
   for f in limit*.nc  ; do cp \$f $local/$LIMIT/\$f ; done
   if [ $aerosols = clim ] ; then  for f in aerosols[.0-9]*nc ; do cp \$f $local/$LIMIT/\$f ; done ; fi
   # 
   if [ $aerosols = spla ] ; then 
     #mkdir -p $local/INPUT_SPLA ; pour l'instant on copie $LMDZ_Init/SPLA_Init en block
     cp -pr $LMDZ_Init/SPLA_Init $local/INPUT_SPLA
   fi
   cd $WRK
...eod
   if [ $ok_guide != y ] ; then # Runing first simulation automatically except for nudging
      cat <<...eod>> tmp
         $submit tmp_$SIM
...eod
   fi
   cat <<...eod>> tmp
# ANCIEN MULTI STEP   esac
...eod

   echo '###############################################################################'
   echo Submitting initialisation job
pwd
   $submit tmp
   echo '###############################################################################'

else
#case [ $init != 1 ] 

   cd $WRK
   echo '###############################################################################'
   echo Submitting job tmp_$SIM
   $submit tmp_$SIM
   echo '###############################################################################'
fi


if [ $ok_guide = y -a $init = 1 ] ; then
   echo Once initialisation is finished, you have to create nudging files
   echo Edit era2gcm.sh and set the desired parameters in section "User choices"
   echo Make sure you have acces to the chosen ERA files, and the required modules are load
   echo Then run : ./era2gcm.sh
   if [ "$aerosols" = "spla" ] ; then
     echo Your aerosol choice is "spla", so you need ERA 10m-winds interpolated on LMDZ grid
     echo Use script era2gcm_uv10m.sh  
   fi
else
   echo Si tout se passe bien, vous avez initialise et lance automatiquement
   echo la simulation.
   echo Si vous voulez modifier les caracteristiques du job, comme le temps
   echo max ou le nombre de proc, il se trouve sur
   echo $SCRATCHD/$MAINDIR/tmp_$SIM
fi

###############################################################################
# At the end, print on screen the compilation command

echo To recompile the model :
echo cd $MODEL
if [ "$fcm" = "-nofcm" ] ; then
    echo   ./makelmdz $optim -p $phylmd $opt_cosp -rrtm true $arch  -d $resol $opt_veget $opt_aer -mem -parallel mpi_omp $arch  gcm ; mkdir -p bin ; \mv -f gcm.e $gcm 
else
    echo  /makelmdz_fcm $optim -p $phylmd $opt_cosp -rrtm true $arch  -j 8 -d $resol $opt_veget $opt_aer -mem -parallel mpi_omp $arch  gcm 
fi

